#
# nfs_volumes.rb
#
# This fact provides an alphabetic list of nfs volumes that are currently
# available and/or accessible on the systems.
#
# This fact was initially written by Matt Moran for local volumes. This
# implementation has been adapted for NFS volumes
#
# Benedikt Wegmann <benedikt.wegmann@gwdg.de>
#

if Facter.value(:kernel) == 'Linux'
  # We store the list of local volumes here ...
  volumes = []

  # We work-around an issue in Facter #10278 by forcing locale settings ...
  ENV['LC_ALL'] = 'C'

  #
  # Get mounts from /proc
  #
  mounts = Facter::Util::Resolution.exec('cat /proc/mounts | grep nfs')
  if mounts.to_s != ''
    mounts.each_line do |line|
      # Remove bloat ...
      line.strip!

      # Parse line and retrieve name of the local volume ...
      volumes << line.split(' ')[1].strip
    end

    Facter.add('nfs_volumes') do
      confine :kernel => :linux
      setcode { volumes.sort.join(',') }
    end
  end
end

# vim: set ts=2 sw=2 et :
# encoding: utf-8
