# Installs and configures nrpe with presets for GWDG.
class ubuntu_server::nrpe($nrpe_local_cfg='puppet:///modules/ubuntu_server/etc/nagios/nrpe_local.cfg',$nrpe_scripts='puppet:///modules/ubuntu_server/opt/nagios',$daemon_options='--no-ssl',$enable_sudo_docker=false){

    File{
        owner => 'root',
        group => 'root',
        mode => 0644
    }

    package{'nagios-nrpe-server':
    ensure => present,
    } ~> Service['nagios-nrpe-server']

    service{'nagios-nrpe-server':
        ensure => running,
    }

    file{'/etc/nagios/nrpe_local.cfg':
        ensure  => present,
        source  => $nrpe_local_cfg,
        require => Package[nagios-nrpe-server],
    } ~> Service['nagios-nrpe-server']

    file{'/etc/default/nagios-nrpe-server':
        ensure  => present,
        content => template('ubuntu_server/etc/default/nagios-nrpe-server.erb'),
        require => Package[nagios-nrpe-server],
    } ~> Service['nagios-nrpe-server']

    file{'/opt/':
        ensure => directory,
    }

    file{'nrpe_scripts':
        ensure  => directory,
        path    => '/opt/nagios',
        mode    => '0755',
        source  => $nrpe_scripts,
        recurse => remote,
        require => Package['nagios-nrpe-server'],
    } ~> Service['nagios-nrpe-server']

    if $enable_sudo_docker == true {
        file_line{'sudoers_1':
            path  => '/etc/sudoers',
            line  => 'nagios ALL=(ALL:ALL) NOPASSWD: /opt/nagios/check_docker_container',
            match => '^nagios ALL=(ALL:ALL) NOPASSWD: /opt/nagios/check_docker_container',
        }
    }

}
