require 'spec_helper'

describe "ubuntu_server::monit" do

  context "with class defaults" do
    let(:facts) {{
      :path => '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
    }}
    it do
      expect {
        is_expected.to compile.with_all_deps
      }.to raise_error(RSpec::Expectations::ExpectationNotMetError)
    end
  end

  context "with $admin_emails=admin@datacenter.com" do
    let(:facts) {{
      :path => '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
      :local_volumes => "/,/opt,/var/lib/docker",
    }}
    let(:params) {{
      :admin_emails => ['admin@datacenter.com'],
    }}
    it { is_expected.to compile.with_all_deps }
    it { is_expected.not_to contain_file('docker_test') }
    it { is_expected.not_to contain_file('/etc/monit/conf.d/docker-ps') }
    it { is_expected.to contain_file('/etc/monit/conf.d/config').with_content(/allow madmin:gEt0ffMyL4wn/) }
    it { is_expected.to contain_file('/etc/monit/conf.d/config').with_content(/set mailserver mailer.gwdg.de/) }
  end

  context "with $docker_check=true" do
    let(:facts) {{
      :path => '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
      :local_volumes => "/,/opt,/var/lib/docker",
    }}
    let(:params) {{
      :admin_emails => ['admin@datacenter.com'],
      :docker_check => true,
    }}
    it { is_expected.to compile.with_all_deps }
    it { is_expected.to contain_file('docker_test') }
    it { is_expected.to contain_file('/etc/monit/conf.d/docker-ps') }
  end

  context "with $puppet_check=true" do
    let(:facts) {{
      :path => '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
      :local_volumes => "/,/opt,/var/lib/docker",
    }}
    let(:params) {{
      :admin_emails => ['admin@datacenter.com'],
      :puppet_check => true,
    }}
    it { is_expected.to compile.with_all_deps }
    it { is_expected.to contain_file('/etc/monit/conf.d/puppet-agent') }
  end

  context "with $admin_user='batman' and admin_passwd='batmobile' and $mailserver='mailer.gotham.com'" do
    let(:facts) {{
      :path => '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
      :local_volumes => "/,/opt,/var/lib/docker",
    }}
    let(:params) {{
      :admin_emails => ['admin@datacenter.com'],
      :admin_user => 'batman',
      :admin_passwd => 'batmobile',
      :mailserver => 'mailer.gotham.com'
    }}
    it { is_expected.to compile.with_all_deps }
    it { is_expected.to contain_file('/etc/monit/conf.d/config').with_content(/allow batman:batmobile/) }
    it { is_expected.to contain_file('/etc/monit/conf.d/config').with_content(/set mailserver mailer.gotham.com/) }
  end

  context "with $monit_config_dir='/some/puppet/url'" do
    let(:facts) {{
      :path => '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
      :local_volumes => "/,/opt,/var/lib/docker",
    }}
    let(:params) {{
      :admin_emails => ['admin@datacenter.com'],
      :monit_config_dir => '/some/puppet/url',
    }}
    it { is_expected.to compile.with_all_deps }
    it { is_expected.to contain_file('monit_configs').with_source('/some/puppet/url') }
  end

end
